marktools.Articulation
======================

.. inheritance-diagram:: abjad.tools.marktools.Articulation.Articulation.Articulation
   :private-bases:

.. autoclass:: abjad.tools.marktools.Articulation.Articulation.Articulation

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.lilypond_format

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.start_component

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.direction

    Inherited from :py:class:`marktools.DirectedMark <abjad.tools.marktools.DirectedMark.DirectedMark.DirectedMark>`

.. autoattribute:: abjad.tools.marktools.Articulation.Articulation.Articulation.name

Methods
-------

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.attach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.detach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__call__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__delattr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__eq__

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__ne__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__repr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Articulation.Articulation.Articulation.__str__
